Module: Samovar::Completion
- Defined in:
- lib/samovar/completion.rb,
lib/samovar/completion/result.rb,
lib/samovar/completion/context.rb,
lib/samovar/completion/provider.rb,
lib/samovar/completion/suggestion.rb
Overview
Shell completion support for Samovar commands.
Defined Under Namespace
Classes: Context, Provider, Result, Suggestion
Class Method Summary collapse
-
.complete(command_class, arguments, environment: ENV) ⇒ Object
Complete the command line for the given command class.
Class Method Details
.complete(command_class, arguments, environment: ENV) ⇒ Object
Complete the command line for the given command class.
20 21 22 |
# File 'lib/samovar/completion.rb', line 20 def self.complete(command_class, arguments, environment: ENV) Context.for(command_class, arguments, environment: environment).complete end |